powered by
A vector of code sequences that mimic the frequency transition matrix and the statistical results reported in Wampold (1984).
A column vector of 200 sequential codes. The data are provided as trial data for the paradom and nonparadom functions.
Wampold, B. E. (1984). Tests of dominance in sequential categorical data. Psychological Bulletin, 96, 424-429.
# NOT RUN { table(data_Wampold_1984) # }
Run the code above in your browser using DataLab